@@ -14,9 +14,10 @@
 ##' @param endNode Optional end node of the path
 ##' @param algorithm Choices of algorithm include "Bfs" (Breadth First Search)
 ##'   and "Dfs" (Depth First Search). Bfs is the default.
-##' @return A list containing three entries: 1) the predecessor of each vertex
-##'   in its shortest path, 2) the distances from each node to the startNode, 3)
-##'   a vector of logicals indicating whether a node was reached.
+##' @return A named list containing three entries: 1) "predecessors": the
+##'   predecessor of each vertex in its shortest path, 2) "distances": the
+##'   distances from each node to the startNode, 3) "node_reached": a vector of
+##'   logicals indicating whether a node was reached.
 ##' @export
 GraphSearch <- function(arcSources,
                         arcTargets,
@@ -35,15 +36,14 @@ GraphSearch <- function(arcSources,
     check_node(endNode, numNodes)
   }
 
-  out <- switch(algorithm,
-                "Bfs" = BfsRunner(arcSources, arcTargets, numNodes,
-                                  startNode, endNode),
-                "Dfs" = DfsRunner(arcSources, arcTargets, numNodes,
-                                  startNode, endNode),
-                stop("Invalid algorithm."))
-
-  out[[3]] <- as.logical(out[[3]])
-  out
+  algfn <- switch(algorithm,
+                  "Bfs" = BfsRunner,
+                  "Dfs" = DfsRunner,
+                  stop("Invalid algorithm."))
+  result <- algfn(arcSources, arcTargets, numNodes, startNode, endNode)
+  result[[3]] <- as.logical(result[[3]])
+  names(result) <- c("predecessors", "distances", "node_reached")
+  result
 }
 
 ##' Runs the maximum cardinality search algorithm on a directed graph. The
@@ -66,8 +66,9 @@ GraphSearch <- function(arcSources,
 ##' @param startNode Optional start node of the path
 ##' @param algorithm Choices of algorithm include "maxcardinalitysearch".
 ##'   maxcardinalitysearch is the default.
-##' @return A list containing two entries: 1) the cardinality of each node , 2)
-##'   a logical vector indicating whether a node was reached or not
+##' @return A named list containing two entries: 1) "cardinalities": the
+##'   cardinality of each node , 2) "node_reached": a logical vector indicating
+##'   whether a node was reached or not
 ##' @export
 MaxCardinalitySearch <- function(arcSources,
                                  arcTargets,
@@ -85,15 +86,12 @@ MaxCardinalitySearch <- function(arcSources,
 
   check_arc_map(arcSources, arcTargets, arcCapacities, numNodes)
 
-  out <- switch(algorithm,
-                "maxcardinalitysearch" =
-                  MaxCardinalitySearchRunner(arcSources,
-                                             arcTargets,
-                                             arcCapacities,
-                                             numNodes,
-                                             startNode),
-                stop("Invalid algorithm."))
-
-  out[[2]] <- as.logical(out[[2]])
-  out
+  algfn <- switch(algorithm,
+                  "maxcardinalitysearch" = MaxCardinalitySearchRunner,
+                  stop("Invalid algorithm.")
+                  )
+  result <- algfn(arcSources, arcTargets, arcCapacities, numNodes, startNode)
+  result[[2]] <- as.logical(result[[2]])
+  names(result) <- c("cardinalities", "node_reached")
+  result
 }
