@@ -1,6 +1,5 @@
-##' Finds the minimum spanning tree of a graph.
-##' The minimum spanning tree is the minimal connected acyclic subgraph of a graph,
-##' assuming the graph is undirected.
+##' The minimum spanning tree is the minimal connected acyclic subgraph of a
+##' graph, assuming the graph is undirected.
 ##'
 ##' For details on LEMON's implementation, including differences between the
 ##' algorithms, see
@@ -15,10 +14,10 @@
 ##' @param numNodes The number of nodes in the graph
 ##' @param algorithm Choices of algorithm include "Kruskal". "Kruskal" is the
 ##'   default.
-##' @return A list containing three entries: 1) A vector corresponding the
-##'   source nodes of the edges in the tree, 2) a vector corresponding the
-##'   target nodes of the edges in the tree, and 3) the total minimum spanning
-##'   tree value.
+##' @return A named list containing three entries: 1) "sources": a vector
+##'   corresponding the source nodes of the edges in the tree, 2) "targets": a
+##'   vector corresponding the target nodes of the edges in the tree, and 3)
+##'   "value": the total minimum spanning tree value.
 ##' @export
 MinSpanningTree <- function(arcSources,
                             arcTargets,
@@ -30,11 +29,13 @@ MinSpanningTree <- function(arcSources,
   check_arc_map(arcSources, arcTargets, arcDistances, numNodes)
   check_algorithm(algorithm)
 
-  switch(algorithm,
-         "Kruskal" = KruskalRunner(arcSources, arcTargets, arcDistances,
-                                   numNodes),
-         stop("Invalid algorithm.")
-         )
+  algfn <- switch(algorithm,
+                  "Kruskal" = KruskalRunner,
+                  stop("Invalid algorithm.")
+                  )
+  result <- algfn(arcSources, arcTargets, arcDistances, numNodes)
+  names(result) <- c("sources", "targets", "value")
+  return(result)
 }
 
 
@@ -54,10 +55,10 @@ MinSpanningTree <- function(arcSources,
 ##' @param numNodes The number of nodes in the graph
 ##' @param algorithm Choices of algorithm include "MinCostArborescence".
 ##'   "MinCostArborescence" is the default.
-##' @return A list containing three entries: 1) A vector corresponding the
-##'   source nodes of the edges in the tree, 2) a vector corresponding the
-##'   target nodes of the edges in the tree, and 3) the total cost of the
-##'   arborescence.
+##' @return A named list containing three entries: 1) "sources": a vector
+##'   corresponding the source nodes of the edges in the tree, 2) "targets": a
+##'   vector corresponding the target nodes of the edges in the tree, and 3)
+##'   "cost": the total cost of the arborescence.
 ##' @export
 MinCostArborescence <- function(arcSources,
                                 arcTargets,
@@ -72,12 +73,11 @@ MinCostArborescence <- function(arcSources,
   check_arc_map(arcSources, arcTargets, arcDistances, numNodes)
   check_algorithm(algorithm)
 
-  switch(algorithm,
-         "MinCostArborescence" = MinCostArborescenceRunner(arcSources,
-                                                           arcTargets,
-                                                           arcDistances,
-                                                           sourceNode,
-                                                           numNodes),
-         stop("Invalid algorithm.")
-         )
+  algfn <- switch(algorithm,
+                  "MinCostArborescence" = MinCostArborescenceRunner,
+                  stop("Invalid algorithm.")
+                  )
+  result <- algfn(arcSources, arcTargets, arcDistances, sourceNode, numNodes)
+  names(result) <- c("sources", "targets", "cost")
+  return(result)
 }
